@@ -3,7 +3,7 @@ import unittest
 
 from mox import MoxTestBase, IsA
 from gevent import Timeout
-import gevent_subprocess
+from gevent import subprocess
 
 from slimta.piperelay import PipeRelay, MaildropRelay, DovecotLdaRelay
 from slimta.relay import TransientRelayError, PermanentRelayError
@@ -13,14 +13,14 @@ from slimta.envelope import Envelope
 class TestPipeRelay(MoxTestBase):
 
     def test_exec_process(self):
-        pmock = self.mox.CreateMock(gevent_subprocess.Popen)
-        self.mox.StubOutWithMock(gevent_subprocess, 'Popen')
+        pmock = self.mox.CreateMock(subprocess.Popen)
+        self.mox.StubOutWithMock(subprocess, 'Popen')
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse('From: sender@example.com\r\n\r\ntest test\r\n')
-        gevent_subprocess.Popen(['relaytest', '-f', 'sender@example.com'],
-                                stdin=gevent_subprocess.PIPE,
-                                stdout=gevent_subprocess.PIPE,
-                                stderr=gevent_subprocess.PIPE).AndReturn(pmock)
+        subprocess.Popen(['relaytest', '-f', 'sender@example.com'],
+                         stdin=subprocess.PIPE,
+                         stdout=subprocess.PIPE,
+                         stderr=subprocess.PIPE).AndReturn(pmock)
         pmock.communicate('From: sender@example.com\r\n\r\ntest test\r\n').AndReturn(('testout', 'testerr'))
         pmock.pid = -1
         pmock.returncode = 0
@@ -32,14 +32,14 @@ class TestPipeRelay(MoxTestBase):
         self.assertEqual('testerr', stderr)
 
     def test_exec_process_error(self):
-        pmock = self.mox.CreateMock(gevent_subprocess.Popen)
-        self.mox.StubOutWithMock(gevent_subprocess, 'Popen')
+        pmock = self.mox.CreateMock(subprocess.Popen)
+        self.mox.StubOutWithMock(subprocess, 'Popen')
         env = Envelope('sender@example.com', ['rcpt@example.com'])
         env.parse('From: sender@example.com\r\n\r\ntest test\r\n')
-        gevent_subprocess.Popen(['relaytest', '-f', 'sender@example.com'],
-                                stdin=gevent_subprocess.PIPE,
-                                stdout=gevent_subprocess.PIPE,
-                                stderr=gevent_subprocess.PIPE).AndReturn(pmock)
+        subprocess.Popen(['relaytest', '-f', 'sender@example.com'],
+                         stdin=subprocess.PIPE,
+                         stdout=subprocess.PIPE,
+                         stderr=subprocess.PIPE).AndReturn(pmock)
         pmock.communicate('From: sender@example.com\r\n\r\ntest test\r\n').AndReturn(('', ''))
         pmock.pid = -1
         pmock.returncode = 1337
